bayespy.nodes.Gaussian
======================

.. currentmodule:: bayespy.nodes

.. autoclass:: Gaussian

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Gaussian.__init__
      ~Gaussian.add_plate_axis
      ~Gaussian.broadcasting_multiplier
      ~Gaussian.delete
      ~Gaussian.get_gradient
      ~Gaussian.get_mask
      ~Gaussian.get_moments
      ~Gaussian.get_parameters
      ~Gaussian.get_riemannian_gradient
      ~Gaussian.get_shape
      ~Gaussian.has_plotter
      ~Gaussian.initialize_from_parameters
      ~Gaussian.initialize_from_prior
      ~Gaussian.initialize_from_random
      ~Gaussian.initialize_from_value
      ~Gaussian.load
      ~Gaussian.logpdf
      ~Gaussian.lower_bound_contribution
      ~Gaussian.lowerbound
      ~Gaussian.move_plates
      ~Gaussian.observe
      ~Gaussian.pdf
      ~Gaussian.plot
      ~Gaussian.random
      ~Gaussian.rotate
      ~Gaussian.rotate_matrix
      ~Gaussian.save
      ~Gaussian.set_parameters
      ~Gaussian.set_plotter
      ~Gaussian.show
      ~Gaussian.unobserve
      ~Gaussian.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Gaussian.dims
      ~Gaussian.plates
      ~Gaussian.plates_multiplier
   
   